@@ -1,6 +1,6 @@
 package POEx::Role::PSGIServer;
 BEGIN {
-  $POEx::Role::PSGIServer::VERSION = '1.101040';
+  $POEx::Role::PSGIServer::VERSION = '1.102530';
 }
 
 #ABSTRACT: Encapsulates core PSGI server behavior
@@ -32,6 +32,22 @@ role POEx::Role::PSGIServer
     );
 
 
+    has wheel_flushers =>
+    (
+        is      => 'ro',
+        traits  => ['Hash'],
+        isa     => 'HashRef',
+        default => sub { {} },
+        handles =>
+        {
+            has_wheel_flusher   => 'exists',
+            get_wheel_flusher   => 'get',
+            set_wheel_flusher   => 'set',
+            clear_wheel_flusher => 'delete',
+        }
+    );
+
+
 
     method BUILDARGS(ClassName $class: @args)
     {
@@ -251,7 +267,26 @@ role POEx::Role::PSGIServer
         POE::Kernel->run();
     }
 
-    with 'POEx::Role::TCPServer' => {-excludes => [qw/ handle_socket_error handle_listen_error/]};
+    method handle_on_flushed(WheelID $id) is Event
+    {
+        if ($self->has_wheel_flusher($id)) {
+            $self->get_wheel_flusher($id)->();
+        }
+        1;
+    }
+
+    after delete_wheel(WheelID $id)
+    {
+        $self->clear_wheel_flusher($id);
+    }
+
+    with 'POEx::Role::TCPServer' =>
+    {
+        -excludes =>
+        [
+            qw/handle_socket_error handle_listen_error handle_on_flushed/
+        ]
+    };
 }
 
 __END__
@@ -263,7 +298,7 @@ POEx::Role::PSGIServer - Encapsulates core PSGI server behavior
 
 =head1 VERSION
 
-version 1.101040
+version 1.102530
 
 =head1 SYNOPSIS
 
@@ -296,6 +331,19 @@ BUILDARGS is provided to translate from the expected Plack::Handler interface to
 
 This attribute stores the PSGI application to be run from this server. A writer method is provided to match the expected Plack::Handler interface
 
+=head1 PROTECTED_ATTRIBUTES
+
+=head2 wheel_flushers
+
+    is: ro, isa: HashRef,
+    exists : has_wheel_flusher,
+    get    : get_wheel_flusher,
+    set    : set_wheel_flusher,
+    delete : clear_wheel_flusher
+
+This attribute stores coderefs to be called on a wheel's flush event
+(necessary to properly handle poll_cb)
+
 =head1 PUBLIC_METHODS
 
 =head2 run
@@ -394,7 +442,7 @@ _write accesses the proper wheel for this context and puts the supplied data int
 
 =head1 AUTHOR
 
-  Nicholas Perez <nperez@cpan.org>
+Nicholas Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
